pub struct AgentContinuation {
pub thread_id: String,
pub provider_model: String,
pub cumulative_input_tokens: u64,
pub cumulative_output_tokens: u64,
pub cumulative_cached_input_tokens: u64,
pub cumulative_reasoning_output_tokens: u64,
}Expand description
Provider state required to continue one native Codex thread with delta accounting.
Fields
thread_id: StringStable native Codex thread identifier.
provider_model: StringExact provider model associated with the thread.
cumulative_input_tokens: u64Cumulative provider input tokens at the last completed turn.
cumulative_output_tokens: u64Cumulative provider output tokens at the last completed turn.
cumulative_cached_input_tokens: u64Cumulative provider cached input tokens at the last completed turn.
cumulative_reasoning_output_tokens: u64Cumulative provider reasoning output tokens at the last completed turn.