pub struct AgentTurn { /* private fields */ }Implementations
Sourceimpl AgentTurn
impl AgentTurn
Sourcepub fn receipt(&self) -> Option<&UsageReceipt>
pub fn receipt(&self) -> Option<&UsageReceipt>
Canonical receipt after the turn has completed or been marked unavailable.
Ends an interrupted turn with unavailable metering and returns its receipt.
pub async fn next_event(&mut self) -> Result<Option<AgentEvent>>
pub async fn respond(&mut self, call_id: &str, result: ToolResult) -> Result<()>