pub struct UsageReceipt {Show 13 fields
pub version: u32,
pub id: Uuid,
pub recorded_at: DateTime<Utc>,
pub user_id: String,
pub operation_id: Option<Uuid>,
pub parent_operation_id: Option<Uuid>,
pub operation: String,
pub requested_model: String,
pub actual_model: String,
pub provider_request_id: Option<String>,
pub provider_thread_id: Option<String>,
pub metering: Metering,
pub cost: Option<CostEstimate>,
}Expand description
Durable evidence for one completed provider call.
Fields
version: u32id: Uuidrecorded_at: DateTime<Utc>user_id: Stringoperation_id: Option<Uuid>Stable identity assigned by the application to this provider call.
parent_operation_id: Option<Uuid>Causal parent operation, when this call is descendant inference.
operation: Stringrequested_model: Stringactual_model: Stringprovider_request_id: Option<String>provider_thread_id: Option<String>metering: Meteringcost: Option<CostEstimate>Locally calculated standard-tier provider cost, when the model and provider usage can be priced.